Module: Libexttextcat

Defined in:
lib/libexttextcat.rb,
lib/libexttextcat/version.rb,
sig/libexttextcat.rbs,
ext/libexttextcat/libexttextcat.c

Overview

-- Copyright (C) 2026 gemmaro

This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program. If not, see https://www.gnu.org/licenses/. ++

Defined Under Namespace

Classes: Candidate, Candidates, Classifier, Error

Constant Summary collapse

VERSION =

Returns:

  • (String)
"0.1.0"